<?
	/**
	 * Patch mouse selection and hover colors in the whole Firefox
	 * theme.
	 */
	function patchColors($dir) {
		// don't replace colors on gnome
		global $theme;
		if(GNOME == $theme) {
			return;			
		}

		replace($dir, '\#C1D2EE', '\#FFD699');
		replace($dir, '\#E0E8F6', '\#FFE5BF');
	}
	
	/**
	 * Replace all instances of a given string for all files in a
	 * given directory.
	 */
	function replace($dir, $from, $to) {
		assert(file_exists('findreplace.sh'));
		
		system('chmod +x findreplace.sh');
		system("./findreplace.sh $from $to $dir");
	}

?>
